from .. import Provider as AddressProvider


class Provider(AddressProvider):
    city_formats = ("{{city_name}}", "{{city_name}}{{city_name_suffix}}")
    building_number_formats = ("%號", "%#號", "%##號")
    postcode_formats = ("%####", "%##")
    section_formats = ("", "", "", "", "%段")
    street_address_formats = ("{{street_name}}{{street_name_suffix}}{{section_number}}{{building_number}}",)
    address_formats = ("{{postcode}} {{city}}{{street_address}}{{secondary_address}}",)
    secondary_address_formats = ("#樓", "之#")

    street_names = (
        "中正",
        "中山",
        "民生",
        "中華",
        "和平",
        "中興",
        "仁愛",
        "復興",
        "民族",
        "民權",
        "忠孝",
        "信義",
        "成功",
        "新興",
        "新生",
        "動物園",
        "淡水",
        "新生",
        "文化",
        "大同",
        "三民",
        "新生",
        "光復",
        "自強",
        "光明",
        "公園",
        "文山",
        "松山",
        "新店",
        "建國",
        "西門",
        "古亭",
        "迴龍",
        "中山",
        "新莊",
        "蘆洲",
        "永安",
        "四維",
        "大橋頭",
        "府中",
        "福德",
        "大同",
        "文昌",
        "土城",
        "博愛",
        "象山",
        "光華",
        "太平",
        "水源",
        "莒光",
        "廣慈",
        "大仁",
        "中央",
        "大智",
        "林森",
        "長春",
        "南",
        "劍南",
        "大坪",
        "國凱" "八德",
        "天母",
        "東興",
        "勝利",
        "頂福州",
        "東湖",
        "大勇",
        "民有",
        "自由",
        "長安",
        "明德",
        "大安",
        "龍山寺",
        "德",
        "忠義",
        "中和",
        "自由",
        "新埔",
        "永和",
        "延平",
        "正義",
        "五福",
        "華興",
        "育英",
        "平和",
        "福安",
        "小碧潭",
        "永寧",
        "育英",
        "興",
        "自立",
        "民享",
        "昆陽",
        "民治",
        "關渡",
        "學府",
        "奇岩",
        "紅樹林",
        "和街",
        "民富",
        "關渡",
        "北投",
        "石牌",
        "芝山",
        "景美",
        "士林",
        "劍潭",
        "雙連",
        "新北投",
        "萬隆",
    )

    street_suffixes = ("路", "街", "巷")

    cities = (
        "基隆",
        "台北",
        "新北",
        "桃園",
        "新竹",
        "新竹",
        "苗栗",
        "台中",
        "彰化",
        "南投",
        "雲林",
        "嘉義",
        "桃園",
        "台南",
        "高雄",
        "屏東",
        "台東",
        "花蓮",
        "宜蘭",
        "澎湖",
        "金門",
        "連江",
        "太保",
        "朴子",
        "馬公",
        "頭份",
        "臺東",
        "斗六",
        "員林",
        "竹北",
        "平鎮",
        "臺中",
        "八德",
        "板橋",
        "大里",
        "鳳山",
        "豐原",
        "蘆洲",
        "蘆竹",
        "三重",
        "樹林",
        "太平",
        "新營",
        "新營",
        "汐止",
        "楊梅",
        "永和",
        "永康",
        "中和",
        "中壢",
        "阿里山",
        "白沙",
        "褒忠",
        "北斗",
        "北竿",
        "北港",
        "卑南",
        "草屯",
        "梅山",
        "牡丹",
        "橫山",
        "光復",
        "關山",
        "古坑",
        "竹田",
    )

    city_suffixes = ("市", "縣")

    # from
    countries = (
        "阿爾巴尼亞",
        "剛果共和國",
        "阿爾及利亞",
        "丹麥",
        "安哥拉",
        "多明尼加",
        "安圭拉",
        "多米尼克",
        "阿根廷",
        "厄瓜多爾",
        "亞美尼亞",
        "埃及",
        "阿路巴",
        "薩爾瓦多",
        "澳大利亞",
        "厄利垂亞",
        "奧地利",
        "愛沙尼亞",
        "亞塞拜然",
        "衣索匹亞",
        "巴哈馬",
        "斐濟",
        "巴林",
        "芬蘭",
        "孟加拉",
        "法屬玻里尼西亞",
        "法國",
        "巴貝多",
        "加彭",
        "白俄羅斯",
        "喬治亞",
        "比利時",
        "德國",
        "貝里斯",
        "迦納",
        "貝南",
        "直布羅陀",
        "百慕達",
        "英國",
        "不丹",
        "希臘",
        "玻利維亞",
        "格瑞那達",
        "波希尼亞及赫塞哥維那",
        "瓜地馬拉",
        "波札那",
        "幾內亞",
        "巴西",
        "蓋亞那",
        "汶萊",
        "海地",
        "保加利亞",
        "宏都拉斯",
        "布吉納法索",
        "香港",
        "蒲隆地",
        "匈牙利",
        "柬埔寨",
        "冰島",
        "喀麥隆",
        "印度",
        "加拿大",
        "印尼",
        "維德角島",
        "依朗",
        "開曼群島",
        "伊拉克",
        "中非共和國",
        "愛爾蘭",
        "查德",
        "以色列",
        "智利",
        "義大利",
        "中國大陸",
        "牙買加",
        "哥倫比亞",
        "日本",
        "剛果",
        "約旦",
        "科克群島",
        "肯亞",
        "哥斯大黎加",
        "韓國",
        "象牙海岸",
        "科威特",
        "克羅埃西亞",
        "寮國",
        "塞浦路斯",
        "拉脫維亞",
        "捷克",
        "賴索托",
        "盧森堡",
        "聖露西亞",
        "澳門",
        "聖文森及格瑞那丁",
        "北馬其頓",
        "聖多美及普林西比",
        "馬達加斯加",
        "沙烏地阿拉伯",
        "馬拉威",
        "塞內加爾",
        "馬來西亞",
        "塞席爾",
        "馬爾地夫",
        "獅子山",
        "馬利",
        "新加坡",
        "馬爾他",
        "斯洛伐克",
        "模里西斯",
        "斯洛維尼亞",
        "茅利塔尼亞",
        "索羅門群島",
        "墨西哥",
        "索馬利亞",
        "摩爾多瓦",
        "南非",
        "蒙古",
        "西班牙",
        "摩洛哥",
        "斯里蘭卡",
        "緬甸",
        "蘇丹",
        "納米比亞",
        "蘇利南",
        "諾魯",
        "史瓦濟蘭",
        "尼泊爾",
        "瑞典",
        "荷蘭",
        "瑞士",
        "新喀里多尼亞",
        "敘利亞",
        "紐西蘭",
        "坦尚尼亞",
        "尼日",
        "泰國",
        "奈及利亞",
        "多哥",
        "挪威",
        "千里達及托貝哥",
        "阿曼",
        "突尼西亞",
        "巴基斯坦",
        "土耳其",
        "巴拿馬",
        "烏干達",
        "巴布亞紐幾內亞",
        "烏克蘭",
        "巴拉圭",
        "阿拉伯聯合大公國",
        "秘魯",
        "美國",
        "菲律賓",
        "烏拉圭",
        "波蘭",
        "委內瑞拉",
        "葡萄牙",
        "越南",
        "卡達",
        "西薩摩亞",
        "羅馬尼亞",
        "葉門",
        "俄羅斯",
        "尚比亞",
        "盧安達",
        "辛巴威",
        "聖克里斯多福及尼維斯",
    )

    def secondary_address(self) -> str:
        return self.numerify(self.random_element(self.secondary_address_formats))

    def building_number(self) -> str:
        return self.numerify(self.random_element(self.building_number_formats))

    def street_name(self) -> str:
        return self.random_element(self.street_names)

    def street_name_suffix(self) -> str:
        return self.random_element(self.street_suffixes)

    def city_name(self) -> str:
        return self.random_element(self.cities)

    def city_name_suffix(self) -> str:
        return self.random_element(self.city_suffixes)

    def section_number(self) -> str:
        return self.numerify(self.random_element(self.section_formats))



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_female = (
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{first_name_female}} {{last_name}}",
    )
    formats_male = (
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{first_name_male}} {{last_name}}",
    )

    # sources: https://ro.wikipedia.org/wiki/List%C4%83_de_prenume_rom%C3%A2ne%C8%99ti
    first_names_female = (
        "Ada",
        "Adela",
        "Adelaida",
        "Adelina",
        "Adina",
        "Adriana",
        "Agata",
        "Aglaia",
        "Agripina",
        "Aida",
        "Alberta",
        "Albertina",
        "Alexandra",
        "Alexandrina",
        "Alice",
        "Alida",
        "Alina",
        "Alis",
        "Alma",
        "Amalia",
        "Amanda",
        "Amelia",
        "Ana",
        "Anabela",
        "Anaida",
        "Anamaria",
        "Anastasia",
        "Anca",
        "Ancuța",
        "Anda",
        "Andra",
        "Andrada",
        "Andreea",
        "Anemona",
        "Aneta",
        "Angela",
        "Anghelina",
        "Anica",
        "Anișoara",
        "Antoaneta",
        "Antonela",
        "Antonia",
        "Anuța",
        "Ariadna",
        "Ariana",
        "Arina",
        "Aristița",
        "Artemisa",
        "Astrid",
        "Atena",
        "Augustina",
        "Aura",
        "Aurelia",
        "Aureliana",
        "Aurica",
        "Aurora",
        "Axenia",
        "Beatrice",
        "Betina",
        "Bianca",
        "Blanduzia",
        "Bogdana",
        "Brândușa",
        "Camelia",
        "Carina",
        "Carla",
        "Carmen",
        "Carmina",
        "Carolina",
        "Casandra",
        "Casiana",
        "Caterina",
        "Catinca",
        "Catrina",
        "Catrinel",
        "Cătălina",
        "Cecilia",
        "Celia",
        "Cerasela",
        "Cezara",
        "Cipriana",
        "Clara",
        "Clarisa",
        "Claudia",
        "Clementina",
        "Cleopatra",
        "Codrina",
        "Codruța",
        "Constanța",
        "Constantina",
        "Consuela",
        "Coralia",
        "Corina",
        "Cornelia",
        "Cosmina",
        "Crenguța",
        "Crina",
        "Cristina",
        "Daciana",
        "Dafina",
        "Daiana",
        "Dalia",
        "Dana",
        "Daniela",
        "Daria",
        "Dariana",
        "Delia",
        "Demetra",
        "Denisa",
        "Despina",
        "Diana",
        "Dida",
        "Didina",
        "Dimitrina",
        "Dina",
        "Dochia",
        "Doina",
        "Domnica",
        "Dora",
        "Doriana",
        "Dorina",
        "Dorli",
        "Draga",
        "Dumitra",
        "Dumitrana",
        "Ecaterina",
        "Eftimia",
        "Elena",
        "Eleonora",
        "Eliana",
        "Elisabeta",
        "Elisaveta",
        "Eliza",
        "Elodia",
        "Elvira",
        "Emanuela",
        "Emilia",
        "Erica",
        "Estera",
        "Eufrosina",
        "Eugenia",
        "Eusebia",
        "Eva",
        "Evanghelina",
        "Evelina",
        "Fabia",
        "Fabiana",
        "Felicia",
        "Filofteia",
        "Fiona",
        "Flavia",
        "Floare",
        "Floarea",
        "Flora",
        "Florența",
        "Florentina",
        "Floriana",
        "Florica",
        "Florina",
        "Francesca",
        "Frusina",
        "Gabriela",
        "Geanina",
        "Gențiana",
        "Georgeta",
        "Georgia",
        "Georgiana",
        "Geta",
        "Gherghina",
        "Gianina",
        "Gina",
        "Giorgiana",
        "Grațiana",
        "Grațiela",
        "Henrieta",
        "Heracleea",
        "Hortensia",
        "Iasmina",
        "Ica",
        "Ileana",
        "Ilinca",
        "Ilona",
        "Ina",
        "Ioana",
        "Ioanina",
        "Iolanda",
        "Ionela",
        "Ionelia",
        "Iosefina",
        "Iridenta",
        "Irina",
        "Iris",
        "Isabela",
        "Iulia",
        "Iuliana",
        "Iustina",
        "Ivona",
        "Izabela",
        "Jana",
        "Janeta",
        "Janina",
        "Jasmina",
        "Jeana",
        "Julia",
        "Julieta",
        "Larisa",
        "Laura",
        "Laurenția",
        "Lavinia",
        "Lăcrămioara",
        "Leana",
        "Lelia",
        "Leontina",
        "Leopoldina",
        "Letiția",
        "Lia",
        "Liana",
        "Lidia",
        "Ligia",
        "Lili",
        "Liliana",
        "Lioara",
        "Livia",
        "Loredana",
        "Lorelei",
        "Lorena",
        "Luana",
        "Lucia",
        "Luciana",
        "Lucreția",
        "Ludmila",
        "Ludovica",
        "Luiza",
        "Luminița",
        "Magdalena",
        "Maia",
        "Malvina",
        "Manuela",
        "Mara",
        "Marcela",
        "Marcheta",
        "Marga",
        "Margareta",
        "Maria",
        "Mariana",
        "Maricica",
        "Marilena",
        "Marina",
        "Marinela",
        "Marioara",
        "Marta",
        "Matilda",
        "Mădălina",
        "Mălina",
        "Mărioara",
        "Măriuca",
        "Melania",
        "Melina",
        "Mihaela",
        "Milena",
        "Mina",
        "Minodora",
        "Mioara",
        "Mirabela",
        "Mirela",
        "Mirona",
        "Miruna",
        "Mona",
        "Monalisa",
        "Monica",
        "Nadia",
        "Narcisa",
        "Natalia",
        "Natașa",
        "Nicoleta",
        "Niculina",
        "Nidia",
        "Noemi",
        "Nora",
        "Norica",
        "Oana",
        "Octavia",
        "Octaviana",
        "Ofelia",
        "Olga",
        "Olimpia",
        "Olivia",
        "Ortansa",
        "Otilia",
        "Ozana",
        "Pamela",
        "Paraschiva",
        "Patricia",
        "Paula",
        "Paulica",
        "Paulina",
        "Petronela",
        "Petruța",
        "Pompilia",
        "Profira",
        "Rada",
        "Rafila",
        "Raluca",
        "Ramona",
        "Rebeca",
        "Renata",
        "Rica",
        "Roberta",
        "Robertina",
        "Rodica",
        "Romanița",
        "Romina",
        "Roxana",
        "Roxelana",
        "Roza",
        "Rozalia",
        "Ruxanda",
        "Ruxandra",
        "Sabina",
        "Sabrina",
        "Safta",
        "Salomea",
        "Sanda",
        "Saveta",
        "Savina",
        "Sânziana",
        "Semenica",
        "Severina",
        "Sidonia",
        "Silvana",
        "Silvia",
        "Silviana",
        "Simina",
        "Simona",
        "Smaranda",
        "Sofia",
        "Sonia",
        "Sorana",
        "Sorina",
        "Speranța",
        "Stana",
        "Stanca",
        "Stela",
        "Steliana",
        "Steluța",
        "Suzana",
        "Svetlana",
        "Ștefana",
        "Ștefania",
        "Tamara",
        "Tania",
        "Tatiana",
        "Teea",
        "Teodora",
        "Teodosia",
        "Teona",
        "Tiberia",
        "Timea",
        "Tinca",
        "Tincuța",
        "Tudora",
        "Tudorița",
        "Tudosia",
        "Valentina",
        "Valeria",
        "Vanesa",
        "Varvara",
        "Vasilica",
        "Venera",
        "Vera",
        "Veronica",
        "Veta",
        "Vicenția",
        "Victoria",
        "Violeta",
        "Viorela",
        "Viorica",
        "Virginia",
        "Viviana",
        "Vlădelina",
        "Voichița",
        "Xenia",
        "Zaharia",
        "Zamfira",
        "Zaraza",
        "Zenobia",
        "Zenovia",
        "Zina",
        "Zoe",
    )

    first_names_male = (
        "Achim",
        "Adam",
        "Adelin",
        "Adi",
        "Adonis",
        "Adrian",
        "Agnos",
        "Albert",
        "Aleodor",
        "Alex",
        "Alexandru",
        "Alexe",
        "Alin",
        "Alistar",
        "Amedeu",
        "Amza",
        "Anatolie",
        "Andrei",
        "Andrian",
        "Angel",
        "Anghel",
        "Antim",
        "Anton",
        "Antonie",
        "Antoniu",
        "Arian",
        "Aristide",
        "Arsenie",
        "Augustin",
        "Aurel",
        "Aurelian",
        "Aurică",
        "Avram",
        "Axinte",
        "Barbu",
        "Bartolomeu",
        "Basarab",
        "Bănel",
        "Bebe",
        "Beniamin",
        "Benone",
        "Bernard",
        "Bogdan",
        "Brăduț",
        "Bucur",
        "Caius",
        "Camil",
        "Cantemir",
        "Carol",
        "Casian",
        "Cazimir",
        "Călin",
        "Cătălin",
        "Cedrin",
        "Cezar",
        "Ciprian",
        "Claudiu",
        "Codin",
        "Codrin",
        "Codruț",
        "Constantin",
        "Cornel",
        "Corneliu",
        "Corvin",
        "Cosmin",
        "Costache",
        "Costel",
        "Costin",
        "Crin",
        "Cristea",
        "Cristian",
        "Cristobal",
        "Cristofor",
        "Dacian",
        "Damian",
        "Dan",
        "Daniel",
        "Darius",
        "David",
        "Decebal",
        "Denis",
        "Dinu",
        "Dominic",
        "Dorel",
        "Dorian",
        "Dorin",
        "Dorinel",
        "Doru",
        "Dragoș",
        "Ducu",
        "Dumitru",
        "Edgar",
        "Edmond",
        "Eduard",
        "Eftimie",
        "Emanoil",
        "Emanuel",
        "Emanuil",
        "Emil",
        "Emilian",
        "Eremia",
        "Eric",
        "Ernest",
        "Eugen",
        "Eusebiu",
        "Eustațiu",
        "Fabian",
        "Felix",
        "Filip",
        "Fiodor",
        "Flaviu",
        "Florea",
        "Florentin",
        "Florian",
        "Florin",
        "Francisc",
        "Frederic",
        "Gabi",
        "Gabriel",
        "Gelu",
        "George",
        "Georgel",
        "Georgian",
        "Ghenadie",
        "Gheorghe",
        "Gheorghiță",
        "Ghiță",
        "Gică",
        "Gicu",
        "Giorgian",
        "Grațian",
        "Gregorian",
        "Grigore",
        "Haralamb",
        "Haralambie",
        "Horațiu",
        "Horea",
        "Horia",
        "Iacob",
        "Iancu",
        "Ianis",
        "Ieremia",
        "Ilarie",
        "Ilarion",
        "Ilie",
        "Inocențiu",
        "Ioan",
        "Ion",
        "Ionel",
        "Ionică",
        "Ionuț",
        "Iosif",
        "Irinel",
        "Iulian",
        "Iuliu",
        "Iurie",
        "Iustin",
        "Iustinian",
        "Ivan",
        "Jan",
        "Jean",
        "Jenel",
        "Ladislau",
        "Lascăr",
        "Laurențiu",
        "Laurian",
        "Lazăr",
        "Leonard",
        "Leontin",
        "Leordean",
        "Lică",
        "Liviu",
        "Lorin",
        "Luca",
        "Lucențiu",
        "Lucian",
        "Lucrețiu",
        "Ludovic",
        "Manole",
        "Marcel",
        "Marcu",
        "Marian",
        "Marin",
        "Marius",
        "Martin",
        "Matei",
        "Maxim",
        "Maximilian",
        "Mădălin",
        "Mihai",
        "Mihail",
        "Mihnea",
        "Mircea",
        "Miron",
        "Mitică",
        "Mitruț",
        "Mugur",
        "Mugurel",
        "Nae",
        "Narcis",
        "Nechifor",
        "Nelu",
        "Nichifor",
        "Nicoară",
        "Nicodim",
        "Nicolae",
        "Nicolaie",
        "Nicu",
        "Niculiță",
        "Nicușor",
        "Nicuță",
        "Norbert",
        "Norman",
        "Octav",
        "Octavian",
        "Octaviu",
        "Olimpian",
        "Olimpiu",
        "Oliviu",
        "Ovidiu",
        "Pamfil",
        "Panagachie",
        "Panait",
        "Paul",
        "Pavel",
        "Pătru",
        "Petre",
        "Petrică",
        "Petrișor",
        "Petru",
        "Petruț",
        "Pleșu",
        "Pompiliu",
        "Radu",
        "Rafael",
        "Rareș",
        "Raul",
        "Răducu",
        "Răzvan",
        "Relu",
        "Remus",
        "Robert",
        "Romeo",
        "Romulus",
        "Sabin",
        "Sandu",
        "Sandu",
        "Sava",
        "Sebastian",
        "Sergiu",
        "Sever",
        "Severin",
        "Silvian",
        "Silviu",
        "Simi",
        "Simion",
        "Sinică",
        "Sorin",
        "Stan",
        "Stancu",
        "Stelian",
        "Șerban",
        "Ștefan",
        "Teodor",
        "Teofil",
        "Teohari",
        "Theodor",
        "Tiberiu",
        "Timotei",
        "Titus",
        "Todor",
        "Toma",
        "Traian",
        "Tudor",
        "Valentin",
        "Valeriu",
        "Valter",
        "Vasile",
        "Vasilică",
        "Veniamin",
        "Vicențiu",
        "Victor",
        "Vincențiu",
        "Viorel",
        "Visarion",
        "Vlad",
        "Vladimir",
        "Vlaicu",
        "Voicu",
        "Zamfir",
        "Zeno",
    )

    first_names = first_names_female + first_names_male

    # sources: https://ro.wikipedia.org/wiki/Lista_celor_mai_uzuale_nume_de_familie#Rom%C3%A2nia
    last_names = (
        "Aanei",
        "Ababei",
        "Albu",
        "Ardelean",
        "Barbu",
        "Cristea",
        "Diaconescu",
        "Diaconu",
        "Dima",
        "Dinu",
        "Dobre",
        "Dochioiu",
        "Dumitrescu",
        "Eftimie",
        "Ene",
        "Florea",
        "Georgescu",
        "Gheorghiu",
        "Ionescu",
        "Ioniță",
        "Manole",
        "Marin",
        "Mazilescu",
        "Mocanu",
        "Nemeș",
        "Nistor",
        "Nistor",
        "Niță",
        "Oprea",
        "Pop",
        "Popa",
        "Popescu",
        "Preda",
        "Pușcașu",
        "Stan",
        "Stancu",
        "Stoica",
        "Stănescu",
        "Suciu",
        "Tabacu",
        "Toma",
        "Tomescu",
        "Tudor",
        "Voinea",
    )



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    first_names_female = (
        "Авгия",
        "Авигея",
        "Авторка",
        "Аглая",
        "Аглоида",
        "Агнешка",
        "Адамина",
        "Адра",
        "Адрианиа",
        "Аела",
        "Айрен",
        "Аксентия",
        "Алания",
        "Албина",
        "Александрина",
        "Алексиа",
        "Аленка",
        "Алиана",
        "Алисия",
        "Алтая",
        "Амбър",
        "Амория",
        "АнаМария",
        "Анатолия",
        "Ангелка",
        "Андика",
        "Андриана",
        "Анелина",
        "анета",
        "Анза",
        "Анимира",
        "Аница",
        "Аномалия",
        "Антоалина",
        "Антонела",
        "Ануша",
        "Анхея-мей",
        "Аполинария",
        "Аралия",
        "Аркадия",
        "Арсена",
        "Аселина",
        "Асифа",
        "Астромерия",
        "Атина",
        "Аурора",
        "Багра",
        "Балина",
        "Бацислава",
        "Беатрис",
        "Бела",
        "Белисима",
        "Беломира",
        "Бенелена",
        "Берислава",
        "Бея",
        "Билена",
        "Бисера",
        "Биянка",
        "Благодатка",
        "Благосвета",
        "Богдалина",
        "Богородка",
        "Бодурка",
        "Божидара-силвестра",
        "Божинела",
        "Божурка",
        "Бонифация",
        "Борена",
        "Бориска",
        "Борянка",
        "Боца",
        "Бригита",
        "Бронислава",
        "Буна",
        "Буча",
        "Бързана",
        "Ваклина",
        "Валерия",
        "Валя",
        "Вангелия",
        "Ванухи",
        "Варта",
        "Васенка",
        "Василина",
        "Васка",
        "Вашиля",
        "Вежда",
        "Велиана",
        "Велинна",
        "Велиянка",
        "Венда",
        "Венеция",
        "Венислава",
        "Венчислава",
        "Верена",
        "Верислава",
        "Веса",
        "Веселинка",
        "Весна",
        "Веца",
        "Видима",
        "Виктория",
        "Вилия",
        "Вилхема",
        "Виолета",
        "Виржиния",
        "Витомира",
        "Вишка",
        "Владилена",
        "Владлена",
        "Водица",
        "Войнка",
        "Вула",
        "Възкресения",
        "Въльо",
        "Върбунка",
        "Въца",
        "Габи",
        "Галена",
        "Галина",
        "Галя",
        "Гануца",
        "Гвоздейка",
        "Гена",
        "Георгелена",
        "Георгица",
        "Герга",
        "Гердана",
        "Гертруда",
        "Гиздана",
        "Гичка",
        "Гордана",
        "Гория",
        "Гоца",
        "Графица",
        "Грета",
        "Гримяна",
        "Гроздинка",
        "Гуна",
        "Гъда",
        "Гълъбица",
        "Гюгра",
        "Гюргя",
        "Дакота",
        "Дамяна",
        "Данелина",
        "Данимира",
        "Данка",
        "Дарданела",
        "Дария",
        "Дафинка",
        "Деа",
        "Деви",
        "Делиана",
        "Деля",
        "Демирела",
        "Дениандра",
        "Дениславена",
        "Денница",
        "Десимиляна",
        "Десияна",
        "Дефлорина",
        "Дея",
        "Джана",
        "Джиневра",
        "Джулия",
        "Диана-Мария",
        "Дида",
        "Дилмана",
        "Димитра",
        "Димка",
        "Динна",
        "Добрина",
        "Дойка",
        "Доменика",
        "Доника",
        "Дора-Анна",
        "Дорина",
        "Доста",
        "Доча",
        "Драгица",
        "Дренка",
        "Дуда",
        "Душка",
        "Дюкяна",
        "Евангелина",
        "Евдокия",
        "Евридика",
        "Едита",
        "Ел",
        "Елдора",
        "Еленица",
        "Елеонета",
        "Ели",
        "Елиз",
        "Елина",
        "Елиса",
        "Елица",
        "Елма",
        "Елфида",
        "Емануила",
        "Емма",
        "Еница",
        "Ергана",
        "Ермиля",
        "Естела",
        "Ефимена",
        "Ефросиния",
        "Жаклин",
        "Жанин",
        "Жара",
        "Жейна",
        "Желязка",
        "Женимира",
        "Жива",
        "Живомира",
        "Жичка",
        "Жорка",
        "Жулиана",
        "Заека",
        "Занка",
        "Зафа",
        "Захаринка",
        "Звездемира",
        "Здравелина",
        "Здухостина",
        "Зинаида",
        "Златея",
        "Златка",
        "Златомира",
        "Зоичка",
        "Зорка",
        "Зузичка",
        "Ивалена",
        "ивамина",
        "Иванеса",
        "Иваничка",
        "Ивелиана",
        "Ивинка",
        "Иглика",
        "Изидора",
        "Илеана",
        "Илианна",
        "Илинда",
        "Илка",
        "Инан",
        "Инеса",
        "Ира",
        "Ирин",
        "Ирла",
        "Исихия",
        "Истилияна",
        "Йоана",
        "Йоанна",
        "Йованка",
        "Йоко",
        "Йолина",
        "Йона",
        "Йоника",
        "Йорданка",
        "Йоханна",
        "Кадифейка",
        "Калея",
        "Калина",
        "Калиса",
        "Калуда",
        "Камея",
        "Кануша",
        "Карамелита",
        "Карина",
        "Касиди",
        "Катастрофа",
        "Катинка",
        "Каунка",
        "Кветослава",
        "Керанка",
        "Кети",
        "Кино",
        "Кирка",
        "Китчица",
        "Клара",
        "Клеуна",
        "Клоя",
        "Кокимира",
        "Комара",
        "Константина",
        "Корнелия",
        "Костадинка",
        "Кралина",
        "Красидара",
        "Красияна",
        "Криси",
        "кристабела",
        "Кристиана",
        "Кристия",
        "Кръстанка",
        "Ксандриния",
        "Кунка",
        "Кьнина",
        "Лада",
        "Лазура",
        "Лалка",
        "Лариса",
        "Лаца",
        "Лека",
        "Ленче",
        "Летисия",
        "Либерта",
        "Лидийка",
        "Лика",
        "Лилия",
        "Лилянка",
        "Линда",
        "Лия",
        "Лозанка",
        "Лорена",
        "Лоти",
        "Луна",
        "Лъчезарка",
        "Любина",
        "Люблина",
        "Любослава",
        "Люляна",
        "Люсила",
        "Лянка",
        "Магдалена",
        "Мадлен",
        "Майя",
        "Максимилияна",
        "Малена",
        "Малтина",
        "Манолина",
        "Мара-антоанета",
        "Маргит",
        "Марен",
        "Мари-анри",
        "Марийка",
        "Маринета",
        "Мариотка",
        "Мария",
        "Мария-елена",
        "Мария-Хуана",
        "Марлена",
        "Маруся",
        "Маса",
        "Матка",
        "Маша",
        "Медиха",
        "Мелания",
        "Мелъди",
        "Меропа",
        "Миглена",
        "Мила",
        "Милара",
        "милдия",
        "Милиана",
        "Милост",
        "Мимоза",
        "Минка",
        "Миранза",
        "Мирена",
        "Миропа",
        "Мисла",
        "Митошка",
        "Михайлена",
        "Мишка",
        "Младлена",
        "Момера",
        "Моника",
        "Мортадела",
        "Мушана",
        "Наводненка",
        "Надка",
        "Найда",
        "Нани",
        "Настия",
        "Наташа",
        "Невена",
        "Негрита",
        "Неделяна",
        "Нейка",
        "Нелида",
        "Нелла",
        "Неолина",
        "Нешка",
        "Нигрита",
        "Никоела",
        "Николина",
        "Нионила",
        "Нона",
        "Норка",
        "Нурета",
        "Огнена",
        "Октавия",
        "Оливера",
        "Омана",
        "Орлеана",
        "Орхидея",
        "Павилия",
        "Павлина",
        "Палвира",
        "Паломина",
        "Панда",
        "Пантера",
        "Парашкевица",
        "Парунка",
        "Патриотка",
        "Паулина",
        "Паца",
        "Пейолина",
        "Пелина",
        "Пепелота",
        "Периана",
        "перуна",
        "Петинка",
        "Петрийка",
        "Петромира",
        "Петрушка",
        "Пешка",
        "Пламена",
        "Плодовитка",
        "Полексина",
        "Полин",
        "Правда",
        "Преса",
        "Прина",
        "Пролетина",
        "Простисвета",
        "Пупи",
        "Първолетка",
        "Рада",
        "Радиа",
        "Радимира",
        "Радка",
        "Радосвета",
        "Радостка",
        "Раинка",
        "Райничка",
        "Рамина",
        "Ревка",
        "Ренгия",
        "Риана",
        "Римма",
        "Рия",
        "Роза",
        "Розана",
        "Розета",
        "Розка",
        "Роксана",
        "Ромолета",
        "Роселина",
        "Росислава",
        "Ростислава",
        "Ружка",
        "Румислава",
        "Русалия",
        "Руска",
        "Сабина",
        "Савета",
        "Салина",
        "Санка",
        "Сарая",
        "Сахория",
        "Свежа",
        "Светла",
        "Светломира",
        "Свидна",
        "Свободка",
        "Севда",
        "севделина",
        "Севета",
        "Семенарка",
        "Сергелинка",
        "Сибила",
        "Сиена",
        "Силви",
        "Силвия-александра",
        "Силяна",
        "Симона",
        "Синтия",
        "Сисоя",
        "Скакалка",
        "Славея",
        "Славка",
        "Сладоледка",
        "Смехотерапия",
        "Смирна",
        "Снежинка",
        "Софийка",
        "Спасена",
        "Спасияна",
        "Спирела",
        "Стависара",
        "Стаматка",
        "Станиела",
        "Станимирка",
        "Сташа",
        "Стелина",
        "Стефани",
        "Стеяна",
        "Стоимена",
        "Столетка",
        "Стоянка",
        "Сузи",
        "Съвестина",
        "Сърменка",
        "Таисия",
        "тамара",
        "Таня",
        "Ташимира",
        "Теа",
        "Телефонка",
        "Темира",
        "Теодора",
        "Теса",
        "Тилиана",
        "Тиха",
        "Тоанета",
        "Толиана",
        "Тона",
        "Тоницвета",
        "Тоска",
        "Тошка",
        "Трендафила",
        "Трифонка",
        "Троша",
        "Труфана",
        "Тръпка",
        "Туфка",
        "Улиана",
        "Урима",
        "Фабияна",
        "Фатиме",
        "Феня",
        "Фикия",
        "Филипини",
        "Фимка",
        "Флавия",
        "Флорика",
        "Фотинка",
        "Фронка",
        "Фуга",
        "Хана",
        "Харитония",
        "Хенриета",
        "Хинка",
        "Холи",
        "Хранислава",
        "Хрисанка",
        "Христа",
        "Христела",
        "Христилияна",
        "Христоелена",
        "Христя",
        "Хубавелка",
        "Цанета",
        "Царевна",
        "Цветана",
        "Цветелина",
        "Цветилена",
        "Цветлина",
        "Цветолилия",
        "Цветяна",
        "Цеца",
        "Цола",
        "Цоня",
        "Чана",
        "Чардафона",
        "Чачия",
        "Череша",
        "Четвърта",
        "Чона",
        "Чубрина",
        "Шана",
        "Шена",
        "Шехерезада",
        "Шинка",
        "Щедра",
        "Щериана",
        "Щефания",
        "Щилянка",
        "Щтилка",
        "Ъгленка",
        "Ъчка",
        "Юлиена",
        "Юлия",
        "Юнона",
        "Юрита",
        "Юстианна",
        "Ябленка",
        "Явора",
        "Ягода",
        "Ялислава",
        "Яна-Мартина",
        "Янина",
        "Яниславия",
        "Янка",
        "Ярка",
        "Ясена",
        "Ятана",
    )

    first_names_male = (
        "Аблен",
        "Август",
        "Августиан",
        "Августин",
        "Авел",
        "Авер",
        "Аверно",
        "Авксентий",
        "Аво",
        "Аврам",
        "Аврели",
        "Аврелий",
        "Аврор",
        "Агапи",
        "Агапий",
        "Агатопод",
        "Агент",
        "Аглай",
        "Агнен",
        "Агнеш",
        "Агоп",
        "Агъци",
        "Адалберт",
        "Адам",
        "Адеан",
        "Аделин",
        "Адем",
        "Адриан",
        "Адриян",
        "Аерозол",
        "Азалия",
        "Айдемир",
        "Акашия",
        "Аксакусти",
        "Аксидан",
        "Аксинтия",
        "Алберт",
        "Албияна",
        "Алдин",
        "Алевандър",
        "Алег",
        "Алек",
        "Алекзандриян",
        "Беримир",
        "Берин",
        "Берия",
        "Беро",
        "Берослав",
        "Бетина",
        "Бетино",
        "Бечо",
        "Билян",
        "Бинко",
        "Биньо",
        "Бисенти",
        "Бисер",
        "Благо",
        "Благовест",
        "Благой",
        "Благомир",
        "Благосвет",
        "Блаже",
        "Бог",
        "Богиня",
        "Богой",
        "Боголюб",
        "Богомил",
        "Богослав",
        "Бодромир",
        "Божан",
        "Божидар",
        "Божик",
        "Божимир",
        "Божин",
        "Божинел",
        "Божко",
        "Божо",
        "Божур",
        "Боил",
        "Боила",
        "Бойко",
        "Бойчо",
        "Болен",
        "Болеслав",
        "Боне",
        "Бонислав",
        "Бонко",
        "Боно",
        "Веселин",
        "Весислав",
        "Весо",
        "Веспасиян",
        "Ветко",
        "Вечко",
        "Вигалот",
        "Виго",
        "Виделин",
        "Виден",
        "Видин",
        "Видослав",
        "Видю",
        "Викенти",
        "Виктор",
        "Вилиан",
        "Вилизар",
        "Вилизара",
        "Вилислав",
        "Вилиян",
        "Винету",
        "Винко",
        "Вино",
        "Винсънт",
        "Винченцо",
        "Виолет",
        "Виолин",
        "Висарион",
        "Виталий",
        "Витко",
        "Витлян",
        "Витомир",
        "Витош",
        "Вихрен",
        "Вихрони",
        "Вихър",
        "Вичо",
        "Виша",
        "Вишетин",
        "Вишню",
        "Влад",
        "Владилен",
        "Владимер",
        "Владимир",
        "Галентин",
        "Галиен",
        "Галимир",
        "Галиян",
        "Гани",
        "Ганислав",
        "Ганцомир",
        "Ганчо",
        "Ганьо",
        "Гаро",
        "Гатьо",
        "Гацо",
        "Гвардиана",
        "Гелемир",
        "Генади",
        "ГенадиВалериев",
        "Генадий",
        "Генислав",
        "Генко",
        "Гено",
        "Генчо",
        "Гео",
        "Геодим",
        "Геомил",
        "Георги",
        "Герасим",
        "Герган",
        "Гергей",
        "Гергелюб",
        "Гергин",
        "Гердан",
        "Герман",
        "Геро",
        "Герой",
        "Герчо",
        "Гетислав",
        "Гетко",
        "Гето",
        "Гецо",
        "Гечо",
        "Гешо",
        "Гивеза",
        "Гиздален",
        "Гико",
        "Гилдрой",
        "Делчо",
        "Делян",
        "Деляна",
        "Демир",
        "Демян",
        "Дениз",
        "Деника",
        "Денимир",
        "Денис",
        "Денислав",
        "Дениян",
        "Денчо",
        "Дердидас",
        "десилиан",
        "Десимир",
        "Десислав",
        "Деслав",
        "Деспин",
        "Деспинка",
        "Деспот",
        "Детелин",
        "Дечко",
        "Дечо",
        "Дечю",
        "Дешо",
        "Деян",
        "Джанер",
        "Джанко",
        "Джихад",
        "Джон-стефан",
        "Диаманди",
        "Диамантина",
        "Диан",
        "Диван(надядоДианидядоИван)",
        "Дивизие",
        "Дивизия",
        "Дивил",
        "Дидко",
        "Диего",
        "Дико",
        "Дилян",
        "Евстати",
        "Евстатий",
        "Евстахий",
        "Евтим",
        "Егор",
        "Едвин",
        "Едит",
        "Едрю",
        "Едуард",
        "Еким",
        "Ектар",
        "Ектор",
        "Елвис",
        "Елеан",
        "Електрон",
        "Елемаг",
        "Еленко",
        "Елиан",
        "Елиас",
        "Елиезер",
        "Елизабет",
        "Елин",
        "Елисей",
        "Елисия",
        "Елко",
        "Ельо",
        "Ема-Бела",
        "Еманоил",
        "Емануел",
        "Емануил",
        "Емил",
        "Емилиан",
        "Емилиян",
        "Ендо",
        "Енчо",
        "Еньо",
        "Еню",
        "Ервин",
        "Ередин",
        "Еремия",
        "Ерик",
        "Ерина",
        "Ерол",
        "Ерсен",
        "Есен",
        "Етиен",
        "Ефка",
        "Заварин",
        "Завен",
        "Замфир",
        "Занго",
        "Занко",
        "Запрян",
        "Зарко",
        "Зафер",
        "Зафир",
        "Захар",
        "Захари",
        "Захарин",
        "Захо",
        "Звездан",
        "Звездин",
        "Звездислав",
        "Звездиян",
        "Звездолет",
        "Звездомир",
        "Згура",
        "Здравелин",
        "Здравец",
        "Здравко",
        "Здравчо",
        "Зенгин",
        "Зика",
        "Зинко",
        "Зинови",
        "Златан",
        "Злати",
        "Златил",
        "Златимир",
        "Златиян",
        "Златко",
        "Златогор",
        "Златозар",
        "Златомир",
        "Златослав",
        "Златоцвет",
        "Златьо",
        "Золтан",
        "Илиомар",
        "Илич",
        "Илия",
        "Илиян",
        "Илко",
        "Илчо",
        "Имилиан",
        "Ингемунд",
        "Инко",
        "Инчо",
        "Иполит",
        "Ириан",
        "Ириней",
        "иринеус",
        "Ириян",
        "Ирко",
        "Ирма",
        "Ирник",
        "Исак",
        "Исидор",
        "Искрен",
        "Искър",
        "Исперих",
        "Истан",
        "Истатко",
        "Истилян",
        "Исус",
        "Итко",
        "Ихтиандър",
        "Ицо",
        "Ичо",
        "Йено",
        "Йеремия",
        "Йоан",
        "Йоан-Александър",
        "Йоан-иво",
        "Йован",
        "Йовица",
        "Йовко",
        "Йово",
        "Йовро",
        "Йовцо",
        "Йовчо",
        "Йожи",
        "Йоил",
        "Йолиян",
        "Йолко",
        "Карен",
        "Карим",
        "Карин",
        "Карло",
        "Кармен",
        "Каролин",
        "Карчо",
        "Катакомб",
        "Каталинка",
        "Катерин",
        "Кевин",
        "Кеворк",
        "Кери",
        "Кибер",
        "Кимба",
        "Кимбо",
        "Кимон",
        "Кимчо",
        "Кин",
        "Кинка",
        "Кинта",
        "Киприслав",
        "Киприян",
        "Кириен",
        "Кирил",
        "Кирчо",
        "Киряк",
        "Киряки",
        "Киряко",
        "Кис",
        "Кит",
        "Кито",
        "Китодар",
        "Китомир",
        "Клим",
        "Климент",
        "Кнут",
        "Козма",
        "Койно",
        "Койо",
        "Койчо",
        "Коко",
        "Коле",
        "Колчо",
        "Кольо",
        "Колю",
        "Комнин",
        "Лалко",
        "Лало",
        "Лальо",
        "Ламби",
        "Ламбо",
        "Ламбю",
        "Ланселот",
        "Ласкал",
        "Ласкар",
        "Ластър",
        "Латин",
        "Латко",
        "Латьо",
        "Латю",
        "ЛЕА-МАРИЯ",
        "Леандър",
        "Лев",
        "Левент",
        "Левчо",
        "Леко",
        "Ленин",
        "Ленко",
        "Леон",
        "Леонид",
        "Лесе",
        "Лефтер",
        "Лечо",
        "Лилко",
        "Лило",
        "Лилчо",
        "Лилян",
        "Лимон",
        "Липе",
        "Лихия",
        "Личо",
        "Ловчо",
        "Лозан",
        "Лозана",
        "Лозен",
        "Лора-софия",
        "Лоранс",
        "Лука",
        "Лукан",
        "Луко",
        "Лули",
        "Лулчо",
        "Лусио",
        "Лусия",
        "Маноел",
        "Манол",
        "Маноло",
        "Мантас",
        "Мануил",
        "Мануш",
        "МанчестърЮнайтед",
        "Манчо",
        "Маньо",
        "Маню",
        "Марангони",
        "Маргарит",
        "Марек",
        "Мариан",
        "Марий",
        "Марин",
        "Маринел",
        "Маринчо",
        "Марио",
        "Мариоллита",
        "Маритна",
        "Мариян",
        "Марк",
        "Марк-антоний",
        "Марко",
        "Маркус",
        "Мартен",
        "Мартин",
        "Мартиниян",
        "Маруш",
        "Марчело",
        "Маслина",
        "Матей",
        "Матьо",
        "Матю",
        "Махно",
        "Машо",
        "Медиан",
        "Мено",
        "Мерилин",
        "Месак",
        "Метакса",
        "Найо",
        "Найчо",
        "Наке",
        "Нако",
        "Нанко",
        "Нано",
        "Нансимир",
        "Нанчо",
        "Наню",
        "Нарцислав",
        "Наско",
        "Настимир",
        "Настрадин",
        "Натанаил",
        "Натко",
        "Наум",
        "Нафисат",
        "Нафтали",
        "Нацко",
        "Нацо",
        "Начиян",
        "Начко",
        "Начо",
        "Невен",
        "Невенко",
        "Невилиян",
        "Невян",
        "Негослав",
        "Неделин",
        "Неделчо",
        "Недислав",
        "Недко",
        "Недьо",
        "Недю",
        "Недялко",
        "Нейко",
        "Нейчо",
        "Нелко",
        "Нелчо",
        "Нене",
        "Ненко",
        "Ненсислав",
        "Ненчо",
        "Неокли",
        "Нерес",
        "Обретим",
        "Ованес",
        "Огин",
        "Огнемир",
        "Огнен",
        "Океан",
        "Олег",
        "Олек",
        "Олимпи",
        "Омар",
        "Омуртаг",
        "Оник",
        "Онуфри",
        "Ончо",
        "Орлин",
        "Ортодокси",
        "Орфей",
        "Орхидей",
        "Орце",
        "Оскар",
        "Оханес",
        "Павел",
        "Павелин",
        "Павко",
        "Павлик",
        "Павлин",
        "Павлинчо",
        "Павломир",
        "Паисий",
        "Пако",
        "Палми",
        "Палмиро",
        "Панай",
        "Панайот",
        "Панде",
        "Панделис",
        "Пане",
        "Панкртийян",
        "Пано",
        "Панталей",
        "Пантелей",
        "Панто",
        "Пантю",
        "Панчо",
        "Паолина",
        "Параскев",
        "Параход",
        "Парашкев",
        "Парашкеван",
        "Паруш",
        "Паско",
        "Паспанахил",
        "Пато",
        "Патрик",
        "Патьо",
        "Паулин",
        "Паун",
        "Пацо",
        "Пачо",
        "Пейко",
        "Пейо",
        "Пейодон",
        "Пейтан",
        "Пейчин",
        "Пейчо",
        "Пеко",
        "Пелай",
        "Пеле",
        "Пенко",
        "Пенчин",
        "Пенчо",
        "Пеньо",
        "Пеню",
        "Пео",
        "Пепино",
        "Пепислав",
        "Пепо",
        "Перикъл",
        "Персиана",
        "Персиян",
        "Перчо",
        "Петиконгрес",
        "Петкан",
        "Петко",
        "Пето",
        "Петраки",
        "Петрана",
        "Петринел",
        "Петрозар",
        "Петромил",
        "Рангел",
        "Рангел-любими",
        "Рандю",
        "Ранчо",
        "Расате",
        "Рафаил",
        "Рачко",
        "Рачо",
        "Рашко",
        "Рашо",
        "Раю",
        "Раян",
        "Реан",
        "Рем",
        "Риналдо",
        "Рис",
        "Ристя",
        "Ричард",
        "Ричерд",
        "Роберт",
        "Роберто",
        "Робин",
        "Робърт",
        "Рогелина",
        "Рогена",
        "Родан",
        "Родион",
        "Розалин",
        "Розин",
        "Розоцвет",
        "Ройо",
        "Роксан",
        "Ромел",
        "Ромелина",
        "Ромен",
        "Ромео",
        "Ромил",
        "Ромул",
        "Росен",
        "Росенка",
        "Росимир",
        "Роска",
        "Роско",
        "Ростиана",
        "Ростимир",
        "Ростислав",
        "Светломир",
        "Светлю",
        "Светозар",
        "Светослав",
        "Себастиан",
        "Себахтин",
        "Севан",
        "Севар",
        "Севастин",
        "Севдалин",
        "Севдан",
        "Севелин",
        "Северин",
        "Седеф",
        "Седефчо",
        "Селен",
        "Селена",
        "Сенко",
        "Серафим",
        "Сергей",
        "Сеслав",
        "Сиви",
        "Сидер",
        "Сидония",
        "Сидор",
        "Сиен",
        "Силаги",
        "Силан",
        "Силвестър",
        "Силвио",
        "Силвиян",
        "Силян",
        "Симеон",
        "Симо",
        "Сирман",
        "Сифоня",
        "Скорбут",
        "Слав",
        "Славдо",
        "Славе",
        "Славейко",
        "Славен",
        "Слави",
        "Славил",
        "Теодоси",
        "Теодосий",
        "Теодослав",
        "Теодостин",
        "Теофан",
        "Теохар",
        "Тервел",
        "Тигрони",
        "Тило",
        "Тильо",
        "Тимо",
        "Тимон",
        "Тимотей",
        "Тимчо",
        "Тино",
        "Тинчо",
        "Тихо",
        "Тихол",
        "Тихомир",
        "Тихон",
        "Тишо",
        "Тоде",
        "Тодомирка",
        "Тодораки",
        "Тодорин",
        "Тодорина",
        "Токимир",
        "Толек",
        "Толю",
        "Тома",
        "Томас",
        "Томен",
        "Томинка",
        "Томислав",
        "Томо",
        "Тоне",
        "Тони",
        "Тонимир",
        "Тонислав",
        "Тонко",
        "Тончо",
        "Топалко",
        "Тополко",
        "Тотко",
        "Тотьо",
        "Тотю",
        "Тоцо",
        "Филатей",
        "Фили",
        "Филидан",
        "Филион",
        "Филип",
        "Филипас",
        "Филипопол",
        "Филко",
        "Филомир",
        "Филчо",
        "Фильо",
        "Финдо",
        "Фиро",
        "Фирчо",
        "Фичо",
        "Флори",
        "Флориан",
        "Флорин",
        "Флоро",
        "Фори",
        "Фосил",
        "Франк",
        "Франц",
        "Францислав",
        "Фрацил",
        "Фреди",
        "Фродо",
        "Фуго",
        "Фуко",
        "Фъстък",
        "Фьодор",
        "Хавтелин",
        "Ханко",
        "Хараламби",
        "Харалампи",
        "Харалан",
        "Харбингър",
        "Хари",
        "Харизан",
        "Харитон",
        "Хасан",
        "Хасатин",
        "Хачо",
        "Хвойне",
        "Хебър",
        "Хектор",
        "Хераклит",
        "Хернани",
        "Хефестион",
        "Химинай",
        "Хинко",
        "Хино",
        "Хитко",
        "Хороз",
        "Храбрин",
        "Храбър",
        "Хранимир",
        "Хрелко",
        "Хрельо",
        "Хрисим",
        "Хрисимир",
        "Хрисо",
        "Христалин",
        "Христивилин",
        "Христиела",
        "Христилиан",
        "християн",
        "Христо",
        "Христо-никола",
        "Христодор",
        "Христозар",
        "Христозорнициан",
        "Христозорницомил",
        "Христомил",
        "Христомир",
        "Христослав",
        "Христофор",
        "Хрисчо",
        "Хрондел",
        "Хрусан",
        "Хубав",
        "Хубавен",
        "Хубан",
        "Хубен",
        "Цоню",
        "Цоцо",
        "Цочо",
        "Цъки",
        "Чавдар",
        "Чанкете",
        "Чанко",
        "Чано",
        "Чаньо",
        "Чардафон",
        "Чародей",
        "Чауш",
        "Чачо",
        "Чвор",
        "Чедомир",
        "Ченко",
        "Ченю",
        "Чепо",
        "Черноризец",
        "Черньо",
        "Чийо",
        "Чико",
        "Чило",
        "Чонар",
        "Чони",
        "Чоно",
        "Чоню",
        "Чочо",
        "Чочомир",
        "Чубрик",
        "Чуде",
        "Чудо",
        "Чудомир",
        "Чудослав",
        "Чук",
        "Шабан",
        "Шанко",
        "Шаноу",
        "Шаро",
        "Шейна",
        "Шеки",
        "Шенко",
        "Шенол",
        "Шибил",
        "Шидер",
        "Шинко",
        "Шино",
        "Шипчан",
        "Ширко",
        "Шишман",
        "Шкодри",
        "Шмильо",
        "Шмулю",
        "Шпилко",
        "Шушо",
        "Щедрин",
        "Щедю",
        "Щеки",
        "Щено",
        "Щеню",
        "Щерион",
        "Щериян",
        "Щерко",
        "Щерьо",
        "Щерю",
        "Щилиян",
        "Щилян",
        "Щирян",
        "Щоно",
        "Щтърбан",
        "Щтъркан",
        "Щурк",
        "Щърбан",
        "Щъркан",
        "Ъглен",
        "Ълен",
        "Ърнест",
        "Ъруин",
        "Ърчо",
        "Ьобирдар",
        "Юги",
        "Юлиан",
        "Юлий",
        "Юлиян",
        "Юрдан",
        "Юри",
        "Юрий",
        "Юстин",
        "Юстиниан",
        "Яблен",
        "Явор",
        "Яго",
        "Ягодин",
        "Язо",
        "Яким",
        "Яко",
        "Якоб",
        "Яков",
        "Якослав",
        "Ян",
        "Янадин",
        "Янаки",
        "Янакин",
        "Яначко",
        "Яне",
        "Янег",
        "Янедин",
        "Янек",
        "Яни",
        "Яниел",
        "Яник",
        "Янимир",
        "Янис",
        "Янислав",
        "Яничко",
        "Янко",
        "Янкул",
        "Яно",
        "Яномил",
        "Янтар",
        "Януш",
        "Янцислав",
        "Янче",
        "Янчо",
        "Ярно",
        "Яромир",
        "Ярце",
        "Ярчо",
        "Яръм",
        "Ярю",
        "Ясен",
        "Ясер",
        "Ястреб",
        "Ятан",
        "Яцо",
        "Ячо",
        "Яшар",
        "Яшка",
        "Яшо",
        "Яшон",
    )

    last_names_male = (
        "Симеонов",
        "Данданов",
        "Кърков",
        "Братухчев",
        "Цветков",
        "Иванов",
        "Яназов",
        "Тодоров",
        "Колчев",
        "Келешев",
        "Бърборков",
        "Дришльов",
        "Макаронски",
        "Количков",
        "Принов",
        "Бодуров",
        "Китов",
        "Гьоков",
        "Симеонов",
        "Балахуров",
        "Милачков",
        "ЕвроповКирилов",
        "Площаков",
        "Мангъров",
        "Хвърчилков",
        "Дзезов",
        "Ждраков",
        "Тухчиев",
        "Топков",
        "Яков",
        "Иликьов",
        "Бурханларски",
        "Вражалски",
        "Тутурилов",
        "Бранков",
        "Зенгинов",
        "Фенеров",
        "Кучев",
        "Възвъзов",
        "Кьоров",
        "Джогов",
        "Пъков",
        "Рангелов",
        "Чутурков",
        "Самсонов",
        "Андонов",
        "Бумов",
        "Мочев",
        "Дачев",
        "Муев",
        "Младенов",
        "Тошев",
        "Бедринов",
        "Тумангелов",
        "Канчин",
        "Миленков",
        "Патков",
        "Пондьов",
        "Самоходов",
        "Четрафилски",
        "Смърдански",
        "Клатуров",
        "Вакрилов",
        "Прошков",
        "Пулев",
        "Парашкевов",
        "Манавски",
        "Чуков",
        "Овнарски",
        "Рошльов",
        "Пройкова",
        "Младенова",
        "Кесьов",
        "Римпопов",
        "Златков",
        "Колев",
        "Пикянски",
        "Николов",
        "Цицков",
        "Стойков",
        "Каракашев",
        "Докова",
        "Мераков",
        "Пеева",
        "Педалов",
        "Тъпчилещов",
        "Въртунински",
        "Кодуков",
        "Татьозов",
        "Токов",
        "Юрганчев",
        "Клатикрушев",
        "Монтянов",
        "Бобев",
        "Топчийски",
        "Луланков",
        "Костов",
        "Колипатков",
        "Чукчуков",
        "Катъров",
        "Кобиларов",
        "Лимонадов",
        "Цоцов",
        "Поаков",
        "Недялков",
        "Станишев",
        "Йорданов",
        "Щърбов",
        "Занов",
    )

    last_names_female = (
        "Кокошкова",
        "Градинарова",
        "Куртакова",
        "Чанлиева",
        "Тодорова",
        "Пътечкова",
        "Скринска",
        "Сапунджиева",
        "Вампирска",
        "Васовa",
        "Таралингова",
        "Илиева",
        "Кривошапкова",
        "Чупетловска",
        "Катърова",
        "Бележкова",
        "Мустакова",
        "Пръндачка",
        "Йоткова",
        "Сланинкова",
        "Мангъфова",
        "Шкембова",
        "Пенджакова",
        "Пачаръзка",
        "Куртажова",
        "Плюнкова",
        "Многознаева",
        "Белоконска-Вражалска",
        "Кучкуделова",
        "Крушовска",
        "Пищовколева",
        "Сопаджиева",
        "Точева-Клопова",
        "Габровлиева",
        "Първанова",
        "Певецова",
        "Яркова",
        "Плюцова",
        "Балканска",
    )

    prefixes_female = ("Г-жа", "Г-ца", "Др.")
    prefixes_male = ("Г-н", "Др.")

    formats_female = (
        "{{first_name_female}} {{last_name_female}}",
        "{{prefix_female}} {{first_name_female}} {{last_name_female}}",
    )

    formats_male = (
        "{{first_name_male}} {{last_name_male}}",
        "{{prefix_female}} {{first_name_male}} {{last_name_male}}",
    )

    formats = formats_male + formats_female
    first_names = first_names_male + first_names_female
    last_names = last_names_male + last_names_female



from collections import OrderedDict

from .. import Provider as ColorProvider

localized = True


class Provider(ColorProvider):
    """Implement color provider for ``id_ID`` locale.

    Sources:
    - https://id.wikipedia.org/wiki/Daftar_warna
    """

    all_colors = OrderedDict(
        (
            ("Abu-abu", "#808080"),
            ("Biru", "#0000FF"),
            ("Biru dongker", "#00008B"),
            ("Biru laut", "#0000CD"),
            ("Biru muda", "#ADD8E6"),
            ("Coklat", "#A52A2A"),
            ("Coklat tua", "#8B4513"),
            ("Emas", "#FFD700"),
            ("Hijau", "#008000"),
            ("Hijau muda", "#90EE90"),
            ("Hijau tua", "#006400"),
            ("Hitam", "#000000"),
            ("Jingga", "#FFA500"),
            ("Kuning", "#FFFF00"),
            ("Koral", "#FF7F50"),
            ("Magenta", "#FF00FF"),
            ("Merah", "#FF0000"),
            ("Merah marun", "#800000"),
            ("Merah jambu", "#FFC0CB"),
            ("Merah bata", "#B22222"),
            ("Perak", "#C0C0C0"),
            ("Nila", "#000080"),
            ("Putih", "#FFFFFF"),
            ("Ungu", "#800080"),
            ("Ungu tua", "#4B0082"),
            ("Zaitun", "#808000"),
        )
    )

    safe_colors = (
        "putih",
        "hitam",
        "merah",
        "hijau",
        "kuning",
        "biru",
        "ungu",
        "abu-abu",
        "coklat",
        "perak",
        "emas",
        "pink",
        "oranye",
    )



from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    formats = (
        "{{last_name}} {{company_suffix}}",
        "{{last_name}} {{last_name}} {{company_suffix}}",
        "{{last_name}}",
    )

    company_suffixes = (
        "AG",
        "AG",
        "AG",
        "AG",
        "AG & Co. KG",
        "AG & Co. KGaA",
        "AG & Co. OHG",
        "GbR",
        "GbR",
        "GmbH",
        "GmbH",
        "GmbH",
        "GmbH",
        "GmbH & Co. KG",
        "GmbH & Co. KG",
        "GmbH & Co. KGaA",
        "GmbH & Co. OHG",
        "KG",
        "KG",
        "KG",
        "KGaA",
        "OHG mbH",
        "Stiftung & Co. KG",
        "Stiftung & Co. KGaA",
        "e.G.",
        "e.V.",
    )



from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    formats = (
        # Local calls
        "#### ####",
        "####-####",
        "####.####",  # domain registrars apparently use this
        "########",
        # National dialing
        "0{{area_code}} #### ####",
        "0{{area_code}}-####-####",
        "0{{area_code}}.####.####",
        "0{{area_code}}########",
        # Optional parenthesis
        "(0{{area_code}}) #### ####",
        "(0{{area_code}})-####-####",
        "(0{{area_code}}).####.####",
        "(0{{area_code}})########",
        # International drops the 0
        "+61 {{area_code}} #### ####",
        "+61-{{area_code}}-####-####",
        "+61.{{area_code}}.####.####",
        "+61{{area_code}}########",
        # 04 Mobile telephones (Australia-wide) mostly commonly written 4 - 3 -
        # 3 instead of 2 - 4 - 4
        "04## ### ###",
        "04##-###-###",
        "04##.###.###",
        "+61 4## ### ###",
        "+61-4##-###-###",
        "+61.4##.###.###",
    )

    def area_code(self) -> str:
        return self.numerify(self.random_element(["2", "3", "7", "8"]))

    def phone_number(self) -> str:
        pattern: str = self.random_element(self.formats)
        return self.numerify(self.generator.parse(pattern))



from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):
    DAY_NAMES = {
        "0": "zondag",
        "1": "maandag",
        "2": "dinsdag",
        "3": "woensdag",
        "4": "donderdag",
        "5": "vrijdag",
        "6": "zaterdag",
    }

    MONTH_NAMES = {
        "01": "januari",
        "02": "februari",
        "03": "maart",
        "04": "april",
        "05": "mei",
        "06": "juni",
        "07": "juli",
        "08": "augustus",
        "09": "september",
        "10": "oktober",
        "11": "november",
        "12": "december",
    }

    def day_of_week(self):
        day = self.date("%w")
        return self.DAY_NAMES[day]

    def month_name(self):
        month = self.month()
        return self.MONTH_NAMES[month]



from collections import OrderedDict

from .. import CreditCard
from .. import Provider as CreditCardProvider


class Provider(CreditCardProvider):
    """Implement credit card provider for ``fa_IR`` locale.

    For all methods that take ``card_type`` as an argument, a random card type
    will be used if the supplied value is ``None``. The list of valid card types
    includes ``'ansar'``, ``'bim'``, ``'day'``, ``'eghtesad_novin'``,
    ``'ghavamin'``, ``'hekmat'``, ``'iran_zamin'``, ``'kar_afarin'``,
    ``'keshavarzi'``, ``'kosar'``, ``'maskan'``, ``'mehre_ghtesad'``,
    ``'meli'``, ``'mellal'``, ``'mellat'``, ``'parsian'``, ``'pasargad'``,
    ``'post_bank'``, ``'refah'``, ``'saderat'``, ``'saman'``, ``'sarmayeh'``,
    ``'sepah'``, ``'shahr'``, ``'sina'``, ``'tat'``, ``'tejarat'``, ``'tose'``,
    and ``'tourism_bank'``.

    Sources:

    - https://way2pay.ir/21653
    """

    prefix_ansar = ["627381"]
    prefix_iran_zamin = ["505785"]
    prefix_hekmat = ["636949"]
    prefix_keshavarzi = ["603770"]
    prefix_shahr = ["502806"]
    prefix_mehr_eghtesad = ["606373"]
    prefix_sarmayeh = ["639607"]
    prefix_post_bank = ["627760"]
    prefix_tose = ["628157"]
    prefix_eghtesad_novin = ["627412"]
    prefix_meli = ["603799"]
    prefix_pasargad = ["502229"]
    prefix_tourism_bank = ["505416"]
    prefix_ghavamin = ["639599"]
    prefix_day = ["502938"]
    prefix_mellat = ["610433"]
    prefix_tejarat = ["585983"]
    prefix_moasse_mellal = ["606256"]
    prefix_saman_bank = ["621986"]
    prefix_kosar = ["505801"]
    prefix_refah = ["589463"]
    prefix_saderat = ["603761"]
    prefix_tat = ["621986"]
    prefix_sina = ["639346"]
    prefix_kar_afarin = ["627488"]
    prefix_sepah = ["589210"]
    prefix_maskan = ["628023"]
    prefix_parsian = ["622106"]
    prefix_bim = ["627961"]

    credit_card_types = OrderedDict(
        (
            ("ansar", CreditCard("انصار", prefix_ansar, 16, security_code="CVV2")),
            (
                "iran_zamin",
                CreditCard("ایران زمین", prefix_iran_zamin, 16, security_code="CVV2"),
            ),
            ("hekmat", CreditCard("حکمت", prefix_hekmat, 16, security_code="CVV2")),
            (
                "keshavarzi",
                CreditCard("کشاورزی", prefix_keshavarzi, 16, security_code="CVV2"),
            ),
            ("shahr", CreditCard("شهر", prefix_shahr, 16, security_code="CVV2")),
            (
                "mehre_ghtesad",
                CreditCard("مهراقتصاد", prefix_mehr_eghtesad, 16, security_code="CVV2"),
            ),
            (
                "sarmayeh",
                CreditCard("سرمایه", prefix_sarmayeh, 16, security_code="CVV2"),
            ),
            (
                "post_bank",
                CreditCard("پست بانک", prefix_post_bank, 16, security_code="CVV2"),
            ),
            ("tose", CreditCard("توسعه", prefix_tose, 16, security_code="CVV2")),
            (
                "eghtesad_novin",
                CreditCard("اقتصاد نوین", prefix_eghtesad_novin, 16, security_code="CVV2"),
            ),
            ("meli", CreditCard("ملی", prefix_meli, 16, security_code="CVV2")),
            (
                "pasargad",
                CreditCard("پاسارگاد", prefix_pasargad, 16, security_code="CVV2"),
            ),
            (
                "tourism_bank",
                CreditCard("گردشگری", prefix_tourism_bank, 16, security_code="CVV2"),
            ),
            (
                "ghavamin",
                CreditCard("قوامین", prefix_ghavamin, 16, security_code="CVV2"),
            ),
            ("day", CreditCard("دی", prefix_day, 16, security_code="CVV2")),
            ("mellat", CreditCard("ملت", prefix_mellat, 16, security_code="CVV2")),
            ("tejarat", CreditCard("تجارت", prefix_tejarat, 16, security_code="CVV2")),
            (
                "mellal",
                CreditCard("ملل", prefix_moasse_mellal, 16, security_code="CVV2"),
            ),
            ("saman", CreditCard("سامان", prefix_saman_bank, 16, security_code="CVV2")),
            ("kosar", CreditCard("کوثر", prefix_kosar, 16, security_code="CVV2")),
            ("refah", CreditCard("رفاه", prefix_refah, 16, security_code="CVV2")),
            ("saderat", CreditCard("صادرات", prefix_saderat, 16, security_code="CVV2")),
            ("tat", CreditCard("تات", prefix_tat, 16, security_code="CVV2")),
            ("sina", CreditCard("سینا", prefix_sina, 16, security_code="CVV2")),
            (
                "kar_afarin",
                CreditCard("کار آفرین", prefix_kar_afarin, 16, security_code="CVV2"),
            ),
            ("sepah", CreditCard("سپه", prefix_sepah, 16, security_code="CVV2")),
            ("maskan", CreditCard("مسکن", prefix_maskan, 16, security_code="CVV2")),
            (
                "parsian",
                CreditCard("پارسیان", prefix_parsian, 16, security_code="CVV2"),
            ),
            ("bim", CreditCard("صنعت و معدن", prefix_bim, 16, security_code="CVV2")),
        )
    )



from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    """Implement automotive provider for ``et_EE`` locale.

    Source:

    - https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Estonia
    """

    license_formats = ("### ???",)



import dataclasses
import sys

from datetime import date, datetime, timedelta
from typing import Sequence, TypeVar, Union

try:
    from typing import Literal  # type: ignore
except ImportError:
    from typing_extensions import Literal  # type: ignore

if sys.version_info >= (3, 9):
    from collections import OrderedDict as OrderedDictType
elif sys.version_info >= (3, 7, 2):
    from typing import OrderedDict as OrderedDictType
else:
    from typing_extensions import OrderedDict as OrderedDictType  # NOQA

DateParseType = Union[date, datetime, timedelta, str, int]
HueType = TypeVar("HueType", str, float, Sequence[int])
SexLiteral = Literal["M", "F"]
SeedType = Union[int, float, str, bytes, bytearray, None]


@dataclasses.dataclass
class Country:
    name: str
    timezones: Sequence[str]
    alpha_2_code: str
    alpha_3_code: str
    continent: str
    capital: str



from ... import BaseProvider


class Provider(BaseProvider):
    """
    Provider for Philippine IDs that are related to social security

    There is no unified social security program in the Philippines. Instead, the Philippines has a messy collection of
    social programs and IDs that, when put together, serves as an analogue of other countries' social security program.
    The government agencies responsible for these programs have relatively poor/outdated information and documentation
    on their respective websites, so the sources section include third party "unofficial" information.

    - Social Security System (SSS) - Social insurance program for workers in private, professional, and informal sectors
    - Government Service Insurance System (GSIS) - Social insurance program for government employees
    - Home Development Mutual Fund (popularly known as Pag-IBIG) - Socialized financial assistance and loaning program
    - Philippine Health Insurance Corporation (PhilHealth) - Social insurance program for health care
    - Unified Multi-Purpose ID (UMID) - Identity card with common reference number (CRN) that serves as a link to
                                        the four previous programs and was planned to supersede the previous IDs, but
                                        its future is now uncertain because of the upcoming national ID system

    Sources:
    - https://www.sss.gov.ph/sss/DownloadContent?fileName=SSSForms_UMID_Application.pdf
    - https://www.gsis.gov.ph/active-members/benefits/ecard-plus/
    - https://www.pagibigfund.gov.ph/DLForms/providentrelated/PFF039_MembersDataForm_V07.pdf
    - https://filipiknow.net/is-umid-and-sss-id-the-same/
    - https://filipiknow.net/philhealth-number/
    - https://en.wikipedia.org/wiki/Unified_Multi-Purpose_ID
    """

    sss_formats = ("##-#######-#",)
    gsis_formats = ("###########",)
    philhealth_formats = ("##-#########-#",)
    pagibig_formats = ("####-####-####",)
    umid_formats = ("####-#######-#",)

    def sss(self) -> str:
        return self.numerify(self.random_element(self.sss_formats))

    def gsis(self) -> str:
        return self.numerify(self.random_element(self.gsis_formats))

    def pagibig(self) -> str:
        return self.numerify(self.random_element(self.pagibig_formats))

    def philhealth(self) -> str:
        return self.numerify(self.random_element(self.philhealth_formats))

    def umid(self) -> str:
        return self.numerify(self.random_element(self.umid_formats))

    def ssn(self) -> str:
        # Use UMID as SSN in the interim till its deprecation
        return self.umid()



from .. import Provider as BankProvider


class Provider(BankProvider):
    """Implement bank provider for ``nl_BE`` locale.

    Information about the Belgian banks can be found on the website
    of the National Bank of Belgium:
    https://www.nbb.be/nl/betalingen-en-effecten/betalingsstandaarden/bankidentificatiecodes
    """

    bban_format = "############"
    country_code = "BE"

    banks = (
        "Argenta Spaarbank",
        "AXA Bank",
        "Belfius Bank",
        "BNP Paribas Fortis",
        "Bpost Bank",
        "Crelan",
        "Deutsche Bank AG",
        "ING België",
        "KBC Bank",
    )
    swift_bank_codes = (
        "ARSP",
        "AXAB",
        "BBRU",
        "BPOT",
        "DEUT",
        "GEBA",
        "GKCC",
        "KRED",
        "NICA",
    )
    swift_location_codes = (
        "BE",
        "B2",
        "99",
        "21",
        "91",
        "23",
        "3X",
        "75",
        "2X",
        "22",
        "88",
        "B1",
        "BX",
        "BB",
    )
    swift_branch_codes = [
        "203",
        "BTB",
        "CIC",
        "HCC",
        "IDJ",
        "IPC",
        "MDC",
        "RET",
        "VOD",
        "XXX",
    ]

    def bank(self) -> str:
        """Generate a bank name."""
        return self.random_element(self.banks)



from typing import Dict

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``fr_FR`` locale.

    Word list is drawn from the French Education Ministry's website Eduscol. The
    "lexical frequency list" can be found in the source(s) below.

    Sources:

    - http://eduscol.education.fr/cid47915/liste-des-mots-classee-par-ordre-alphabetique.html
    """

    word_list = (
        "à",
        "abandonner",
        "abattre",
        "abri",
        "absence",
        "absolu",
        "absolument",
        "accent",
        "accepter",
        "accompagner",
        "accomplir",
        "accord",
        "accorder",
        "accrocher",
        "accuser",
        "acheter",
        "achever",
        "acte",
        "action",
        "admettre",
        "adresser",
        "affaire",
        "affirmer",
        "afin de",
        "âgé",
        "âge",
        "agent",
        "agir",
        "agiter",
        "ah",
        "aide",
        "aider",
        "aile",
        "ailleurs",
        "aimer",
        "ainsi",
        "air",
        "ajouter",
        "aller",
        "allumer",
        "alors",
        "âme",
        "amener",
        "ami",
        "amour",
        "amuser",
        "an",
        "ancien",
        "anglais",
        "anglais",
        "angoisse",
        "animal",
        "animer",
        "année",
        "annoncer",
        "apercevoir",
        "apparaître",
        "apparence",
        "appartement",
        "appartenir",
        "appel",
        "appeler",
        "apporter",
        "apprendre",
        "approcher",
        "appuyer",
        "après",
        "après",
        "arbre",
        "argent",
        "arme",
        "armée",
        "armer",
        "arracher",
        "arrêter",
        "arrière",
        "arrivée",
        "arriver",
        "art",
        "article",
        "as",
        "aspect",
        "asseoir",
        "assez",
        "assister",
        "assurer",
        "attacher",
        "attaquer",
        "atteindre",
        "attendre",
        "attention",
        "attirer",
        "attitude",
        "au",
        "aucun",
        "aucun",
        "aujourd'hui",
        "auprès",
        "auquel",
        "aussi",
        "aussitôt",
        "autant",
        "auteur",
        "autorité",
        "autour",
        "autre",
        "autre",
        "autrefois",
        "autrement",
        "avance",
        "avancer",
        "avant",
        "avant",
        "avec",
        "avec",
        "avenir",
        "aventure",
        "avis",
        "avoir",
        "avouer",
        "baisser",
        "banc",
        "bande",
        "barbe",
        "bas",
        "bas",
        "bas",
        "bataille",
        "battre",
        "beau",
        "beau",
        "beau",
        "beaucoup",
        "beauté",
        "beaux",
        "besoin",
        "bête",
        "bien",
        "bien",
        "bientôt",
        "billet",
        "blanc",
        "blanc",
        "bleu",
        "blond",
        "boire",
        "bois",
        "bon",
        "bon",
        "bonheur",
        "bord",
        "bouche",
        "bout",
        "branche",
        "bras",
        "briller",
        "briser",
        "bruit",
        "brûler",
        "brusquement",
        "bureau",
        "but",
        "ça",
        "cabinet",
        "cacher",
        "calme",
        "calme",
        "calmer",
        "camarade",
        "campagne",
        "capable",
        "car",
        "caractère",
        "caresser",
        "carte",
        "cas",
        "casser",
        "cause",
        "causer",
        "ce",
        "ce",
        "ceci",
        "céder",
        "cela",
        "celui",
        "cent",
        "centre",
        "cependant",
        "cercle",
        "certain",
        "certain",
        "certainement",
        "certes",
        "cerveau",
        "cesse",
        "cesser",
        "chacun",
        "chaîne",
        "chair",
        "chaise",
        "chaleur",
        "chambre",
        "champ",
        "chance",
        "changement",
        "changer",
        "chant",
        "chanter",
        "chaque",
        "charge",
        "charger",
        "chasse",
        "chasser",
        "chat",
        "chaud",
        "chef",
        "chemin",
        "chemise",
        "cher",
        "chercher",
        "cheval",
        "cheveu",
        "chez",
        "chien",
        "chiffre",
        "choisir",
        "choix",
        "chose",
        "chute",
        "ci",
        "ciel",
        "cinq",
        "cinquante",
        "circonstance",
        "clair",
        "claire",
        "classe",
        "clef",
        "coeur",
        "coin",
        "colère",
        "colline",
        "colon",
        "combat",
        "combien",
        "commander",
        "comme",
        "comme",
        "commencement",
        "commencer",
        "comment",
        "comment",
        "commun",
        "compagnie",
        "compagnon",
        "complet",
        "complètement",
        "composer",
        "comprendre",
        "compte",
        "compter",
        "conclure",
        "condamner",
        "condition",
        "conduire",
        "confiance",
        "confier",
        "confondre",
        "connaissance",
        "connaître",
        "conscience",
        "conseil",
        "consentir",
        "considérer",
        "construire",
        "consulter",
        "contenir",
        "content",
        "contenter",
        "continuer",
        "contraire",
        "contre",
        "convenir",
        "conversation",
        "corde",
        "corps",
        "côte",
        "côté",
        "cou",
        "couche",
        "coucher",
        "couler",
        "couleur",
        "coup",
        "couper",
        "cour",
        "courage",
        "courant",
        "courir",
        "cours",
        "course",
        "court",
        "coûter",
        "couvrir",
        "craindre",
        "crainte",
        "créer",
        "creuser",
        "cri",
        "crier",
        "crise",
        "croire",
        "croiser",
        "croix",
        "cruel",
        "cuisine",
        "curieux",
        "curiosité",
        "d'abord",
        "dame",
        "danger",
        "dangereux",
        "dans",
        "danser",
        "d'autres",
        "d'autres",
        "davantage",
        "de",
        "de",
        "debout",
        "début",
        "déchirer",
        "décider",
        "déclarer",
        "découvrir",
        "décrire",
        "défaut",
        "défendre",
        "dégager",
        "dehors",
        "dehors",
        "déjà",
        "delà",
        "demain",
        "demain",
        "demande",
        "demander",
        "demeurer",
        "demi",
        "dent",
        "départ",
        "dépasser",
        "déposer",
        "depuis",
        "depuis",
        "dernier",
        "dernier",
        "derrière",
        "dès",
        "descendre",
        "désert",
        "désespoir",
        "désigner",
        "désir",
        "désirer",
        "désormais",
        "dessiner",
        "dessus",
        "détacher",
        "détail",
        "détruire",
        "deux",
        "devant",
        "devant",
        "devenir",
        "deviner",
        "devoir",
        "devoir",
        "dieu",
        "différent",
        "difficile",
        "digne",
        "dimanche",
        "dire",
        "direction",
        "diriger",
        "discours",
        "discussion",
        "discuter",
        "disparaître",
        "disposer",
        "distance",
        "distinguer",
        "divers",
        "dix",
        "docteur",
        "doigt",
        "dominer",
        "donc",
        "donner",
        "dont",
        "dormir",
        "dos",
        "double",
        "doucement",
        "douceur",
        "douleur",
        "doute",
        "douter",
        "doux",
        "douze",
        "drame",
        "dresser",
        "droit",
        "droit",
        "droite",
        "droite",
        "drôle",
        "du",
        "dur",
        "durant",
        "durer",
        "eau",
        "eaux",
        "écarter",
        "échapper",
        "éclairer",
        "éclat",
        "éclater",
        "école",
        "écouter",
        "écraser",
        "écrire",
        "effacer",
        "effet",
        "effort",
        "égal",
        "également",
        "eh",
        "élément",
        "élever",
        "elle",
        "éloigner",
        "embrasser",
        "emmener",
        "émotion",
        "empêcher",
        "empire",
        "employer",
        "emporter",
        "en",
        "en",
        "en",
        "encore",
        "endormir",
        "endroit",
        "énergie",
        "enfance",
        "enfant",
        "enfermer",
        "enfin",
        "enfoncer",
        "engager",
        "enlever",
        "ennemi",
        "énorme",
        "ensemble",
        "ensemble",
        "ensuite",
        "entendre",
        "entier",
        "entourer",
        "entraîner",
        "entre",
        "entrée",
        "entrer",
        "entretenir",
        "envelopper",
        "envie",
        "environ",
        "envoyer",
        "épais",
        "épaule",
        "époque",
        "éprouver",
        "erreur",
        "escalier",
        "espace",
        "espèce",
        "espérer",
        "espoir",
        "esprit",
        "essayer",
        "essuyer",
        "est",
        "et",
        "établir",
        "étage",
        "étaler",
        "état",
        "etc",
        "été",
        "éteindre",
        "étendre",
        "étendue",
        "éternel",
        "étoile",
        "étonner",
        "étouffer",
        "étrange",
        "étranger",
        "étranger",
        "être",
        "être",
        "étroit",
        "étude",
        "étudier",
        "événement",
        "éviter",
        "examiner",
        "exécuter",
        "exemple",
        "exiger",
        "existence",
        "exister",
        "expérience",
        "expliquer",
        "exposer",
        "expression",
        "exprimer",
        "extraordinaire",
        "face",
        "facile",
        "façon",
        "faible",
        "faim",
        "faire",
        "fait",
        "fait",
        "falloir",
        "famille",
        "fatigue",
        "fatiguer",
        "faute",
        "fauteuil",
        "faux",
        "faveur",
        "femme",
        "fenêtre",
        "fer",
        "ferme",
        "fermer",
        "fête",
        "feu",
        "feuille",
        "fidèle",
        "fier",
        "figure",
        "figurer",
        "fil",
        "fille",
        "fils",
        "fin",
        "fin",
        "fine",
        "finir",
        "fixe",
        "fixer",
        "flamme",
        "fleur",
        "flot",
        "foi",
        "fois",
        "folie",
        "fonction",
        "fond",
        "fonder",
        "force",
        "forcer",
        "forêt",
        "forme",
        "former",
        "fort",
        "fort",
        "fortune",
        "fou",
        "foule",
        "frais",
        "franc",
        "français",
        "français",
        "franchir",
        "françois",
        "frapper",
        "frère",
        "froid",
        "froid",
        "front",
        "fruit",
        "fuir",
        "fumée",
        "fumer",
        "fusil",
        "gagner",
        "garçon",
        "garde",
        "garder",
        "gauche",
        "gauche",
        "général",
        "général",
        "genou",
        "genre",
        "gens",
        "geste",
        "glace",
        "glisser",
        "gloire",
        "goût",
        "goutte",
        "gouvernement",
        "grâce",
        "grâce",
        "grain",
        "grand",
        "grand",
        "grandir",
        "grave",
        "gris",
        "gros",
        "groupe",
        "guère",
        "guerre",
        "habiller",
        "habitant",
        "habiter",
        "habitude",
        "haine",
        "haïr",
        "hasard",
        "haut",
        "haut",
        "haut",
        "haute",
        "hauteur",
        "herbe",
        "hésiter",
        "heure",
        "heureux",
        "hier",
        "histoire",
        "hiver",
        "homme",
        "honneur",
        "honte",
        "horizon",
        "hors",
        "hôtel",
        "huit",
        "humain",
        "humide",
        "ici",
        "idée",
        "ignorer",
        "il",
        "île",
        "image",
        "imaginer",
        "immense",
        "immobile",
        "importance",
        "important",
        "importer",
        "imposer",
        "impossible",
        "impression",
        "inconnu",
        "indiquer",
        "inquiéter",
        "inquiétude",
        "inspirer",
        "installer",
        "instant",
        "instinct",
        "intelligence",
        "intention",
        "intéresser",
        "intérêt",
        "intérieur",
        "intérieur",
        "interroger",
        "interrompre",
        "inutile",
        "inventer",
        "inviter",
        "jamais",
        "jambe",
        "jardin",
        "jaune",
        "je",
        "jeter",
        "jeu",
        "jeune",
        "jeune",
        "jeunesse",
        "joie",
        "joindre",
        "joli",
        "joue",
        "jouer",
        "jour",
        "journal",
        "journée",
        "juge",
        "juger",
        "jusque",
        "juste",
        "justice",
        "là",
        "large",
        "larme",
        "le",
        "le",
        "léger",
        "lendemain",
        "lentement",
        "lequel",
        "lettre",
        "leur",
        "leur",
        "lever",
        "lèvre",
        "liberté",
        "libre",
        "lien",
        "lier",
        "lieu",
        "ligne",
        "lire",
        "lisser",
        "lit",
        "livre",
        "livrer",
        "loi",
        "loin",
        "long",
        "long",
        "longtemps",
        "lors",
        "lorsque",
        "loup",
        "lourd",
        "lueur",
        "lui",
        "lumière",
        "l'un",
        "l'une",
        "lune",
        "lutte",
        "lutter",
        "machine",
        "madame",
        "magnifique",
        "main",
        "maintenant",
        "maintenir",
        "mais",
        "maison",
        "maître",
        "mal",
        "mal",
        "malade",
        "maladie",
        "malgré",
        "malheur",
        "manger",
        "manier",
        "manquer",
        "marchand",
        "marché",
        "marche",
        "marcher",
        "mari",
        "mari",
        "mariage",
        "marier",
        "marquer",
        "masse",
        "matière",
        "matin",
        "mauvais",
        "me",
        "médecin",
        "meilleur",
        "mêler",
        "membre",
        "même",
        "même",
        "même",
        "mémoire",
        "menacer",
        "mener",
        "mensonge",
        "mentir",
        "mer",
        "mériter",
        "mesure",
        "métier",
        "mettre",
        "midi",
        "mien",
        "mieux",
        "milieu",
        "militaire",
        "mille",
        "million",
        "mince",
        "mine",
        "ministre",
        "minute",
        "miser",
        "mode",
        "moi",
        "moindre",
        "moins",
        "mois",
        "moitié",
        "moment",
        "mon",
        "monde",
        "monsieur",
        "montagne",
        "monter",
        "montrer",
        "morceau",
        "mort",
        "mort",
        "mot",
        "mourir",
        "mouvement",
        "moyen",
        "moyen",
        "muet",
        "mur",
        "musique",
        "naissance",
        "naître",
        "nation",
        "nature",
        "naturel",
        "naturellement",
        "ne",
        "nécessaire",
        "nerveux",
        "neuf",
        "neuf",
        "nez",
        "ni",
        "noir",
        "noir",
        "noire",
        "nom",
        "nombre",
        "nombreux",
        "nommer",
        "non",
        "nord",
        "note",
        "notre",
        "nourrir",
        "nous",
        "nouveau",
        "nouveau",
        "nu",
        "nuage",
        "nuit",
        "nul",
        "obéir",
        "objet",
        "obliger",
        "observer",
        "obtenir",
        "occasion",
        "occuper",
        "odeur",
        "oeil",
        "oeuvre",
        "officier",
        "offrir",
        "oh",
        "oiseau",
        "ombre",
        "on",
        "oncle",
        "or",
        "or",
        "ordre",
        "oreille",
        "oser",
        "ou",
        "où",
        "oublier",
        "oui",
        "ouvert",
        "ouvrage",
        "ouvrir",
        "page",
        "pain",
        "paix",
        "palais",
        "papa",
        "papier",
        "paquet",
        "par",
        "paraître",
        "parce que",
        "parcourir",
        "pareil",
        "parent",
        "parfaitement",
        "parfois",
        "parler",
        "parmi",
        "parole",
        "part",
        "partager",
        "parti",
        "particulier",
        "partie",
        "partir",
        "partout",
        "parvenir",
        "pas",
        "pas",
        "passage",
        "passé",
        "passé",
        "passer",
        "passion",
        "patron",
        "paupière",
        "pauvre",
        "pauvre",
        "payer",
        "pays",
        "paysage",
        "paysan",
        "peau",
        "peine",
        "pencher",
        "pendant",
        "pendre",
        "pénétrer",
        "pensée",
        "penser",
        "perdre",
        "perdu",
        "père",
        "permettre",
        "personnage",
        "personne",
        "personne",
        "perte",
        "peser",
        "petit",
        "petit",
        "peu",
        "peuple",
        "peur",
        "phrase",
        "pièce",
        "pied",
        "pierre",
        "pitié",
        "place",
        "placer",
        "plaindre",
        "plaine",
        "plaire",
        "plaisir",
        "plan",
        "planche",
        "plante",
        "plein",
        "plein",
        "pleurer",
        "plonger",
        "pluie",
        "plus",
        "plusieurs",
        "plutôt",
        "poche",
        "poésie",
        "poète",
        "poids",
        "point",
        "point",
        "pointe",
        "poitrine",
        "police",
        "politique",
        "politique",
        "pont",
        "port",
        "porte",
        "porter",
        "portier",
        "poser",
        "position",
        "posséder",
        "possible",
        "poste",
        "pour",
        "pourquoi",
        "pourquoi",
        "poursuivre",
        "pourtant",
        "pousser",
        "poussière",
        "pouvoir",
        "pouvoir",
        "précéder",
        "précieux",
        "précipiter",
        "précis",
        "préférer",
        "premier",
        "premier",
        "prendre",
        "préparer",
        "près",
        "près",
        "présence",
        "présent",
        "présent",
        "présenter",
        "président",
        "presque",
        "presser",
        "prêt",
        "prétendre",
        "prêter",
        "preuve",
        "prévenir",
        "prévoir",
        "prier",
        "prière",
        "prince",
        "principe",
        "printemps",
        "prison",
        "prix",
        "problème",
        "prochain",
        "produire",
        "professeur",
        "profiter",
        "profond",
        "profondément",
        "projet",
        "promener",
        "promettre",
        "prononcer",
        "propos",
        "proposer",
        "propre",
        "protéger",
        "prouver",
        "public",
        "public",
        "puis",
        "puis",
        "puisque",
        "puissance",
        "puissant",
        "pur",
        "qualité",
        "quand",
        "quant à",
        "quarante",
        "quart",
        "quartier",
        "quatre",
        "que",
        "que",
        "quel",
        "quelque",
        "quelque",
        "quelqu'un",
        "question",
        "queue",
        "qui",
        "quinze",
        "quitter",
        "quoi",
        "race",
        "raconter",
        "raison",
        "ramasser",
        "ramener",
        "rang",
        "rapide",
        "rapidement",
        "rappeler",
        "rapport",
        "rapporter",
        "rare",
        "rassurer",
        "rayon",
        "réalité",
        "recevoir",
        "recherche",
        "réclamer",
        "recommencer",
        "reconnaître",
        "recueillir",
        "reculer",
        "réduire",
        "réel",
        "réfléchir",
        "réflexion",
        "refuser",
        "regard",
        "regarder",
        "règle",
        "regretter",
        "rejeter",
        "rejoindre",
        "relation",
        "relever",
        "religion",
        "remarquer",
        "remercier",
        "remettre",
        "remonter",
        "remplacer",
        "remplir",
        "rencontre",
        "rencontrer",
        "rendre",
        "renoncer",
        "rentrer",
        "renverser",
        "répandre",
        "repas",
        "répéter",
        "répondre",
        "réponse",
        "reposer",
        "repousser",
        "reprendre",
        "représenter",
        "réserver",
        "résistance",
        "résister",
        "résoudre",
        "respect",
        "respecter",
        "respirer",
        "ressembler",
        "reste",
        "rester",
        "résultat",
        "retenir",
        "retirer",
        "retomber",
        "retour",
        "retourner",
        "retrouver",
        "réunir",
        "réussir",
        "rêve",
        "réveiller",
        "révéler",
        "revenir",
        "rêver",
        "revoir",
        "révolution",
        "riche",
        "rideau",
        "rien",
        "rire",
        "rire",
        "risquer",
        "robe",
        "roche",
        "rocher",
        "roi",
        "rôle",
        "roman",
        "rompre",
        "rond",
        "rose",
        "rose",
        "rouge",
        "rouge",
        "rouler",
        "route",
        "rue",
        "ruine",
        "sable",
        "sac",
        "saint",
        "saint",
        "saisir",
        "saison",
        "salle",
        "saluer",
        "salut",
        "sang",
        "sans",
        "santé",
        "satisfaire",
        "sauter",
        "sauvage",
        "sauver",
        "savoir",
        "savoir",
        "scène",
        "science",
        "se",
        "sec",
        "second",
        "seconde",
        "secours",
        "secret",
        "secret",
        "secrétaire",
        "seigneur",
        "sein",
        "selon",
        "semaine",
        "semblable",
        "sembler",
        "sens",
        "sentier",
        "sentiment",
        "sentir",
        "séparer",
        "sept",
        "sérieux",
        "serrer",
        "service",
        "servir",
        "seuil",
        "seul",
        "seulement",
        "si",
        "si",
        "siècle",
        "siège",
        "sien",
        "signe",
        "signer",
        "signifier",
        "silence",
        "silencieux",
        "simple",
        "simplement",
        "situation",
        "six",
        "social",
        "société",
        "soi",
        "soin",
        "soir",
        "soirée",
        "soit",
        "sol",
        "soldat",
        "soleil",
        "solitude",
        "sombre",
        "somme",
        "sommeil",
        "sommet",
        "son",
        "son",
        "songer",
        "sonner",
        "sorte",
        "sortir",
        "sou",
        "soudain",
        "souffler",
        "souffrance",
        "souffrir",
        "souhaiter",
        "soulever",
        "soumettre",
        "source",
        "sourd",
        "sourire",
        "sourire",
        "sous",
        "soutenir",
        "souvenir",
        "souvenir",
        "souvent",
        "spectacle",
        "subir",
        "succès",
        "sueur",
        "suffire",
        "suite",
        "suivant",
        "suivre",
        "sujet",
        "supérieur",
        "supporter",
        "supposer",
        "sûr",
        "sur",
        "surprendre",
        "surtout",
        "surveiller",
        "système",
        "table",
        "tâche",
        "tache",
        "taille",
        "taire",
        "tandis que",
        "tant",
        "tantôt",
        "tapis",
        "tard",
        "te",
        "tel",
        "tellement",
        "témoin",
        "tempête",
        "temps",
        "tendre",
        "tendre",
        "tenir",
        "tenter",
        "terme",
        "terminer",
        "terrain",
        "terre",
        "terreur",
        "terrible",
        "tête",
        "théâtre",
        "tirer",
        "titre",
        "toi",
        "toile",
        "toit",
        "tombe",
        "tomber",
        "ton",
        "ton",
        "tôt",
        "toucher",
        "toujours",
        "tour",
        "tourner",
        "tout",
        "tout",
        "tout",
        "tout",
        "toute",
        "trace",
        "tracer",
        "train",
        "traîner",
        "trait",
        "traiter",
        "tranquille",
        "transformer",
        "travail",
        "travailler",
        "travers",
        "traverser",
        "trembler",
        "trente",
        "très",
        "trésor",
        "triste",
        "trois",
        "troisième",
        "tromper",
        "trop",
        "trou",
        "troubler",
        "trouver",
        "tu",
        "tuer",
        "type",
        "un",
        "un",
        "un",
        "unique",
        "usage",
        "user",
        "vague",
        "vague",
        "vaincre",
        "valeur",
        "valoir",
        "vaste",
        "veille",
        "veiller",
        "vendre",
        "venir",
        "vent",
        "ventre",
        "véritable",
        "vérité",
        "verre",
        "vers",
        "vers",
        "verser",
        "vert",
        "vêtement",
        "vêtir",
        "victime",
        "vide",
        "vide",
        "vie",
        "vieil",
        "vieillard",
        "vieux",
        "vieux",
        "vif",
        "village",
        "ville",
        "vin",
        "vingt",
        "violence",
        "violent",
        "visage",
        "visible",
        "vision",
        "visite",
        "vite",
        "vivant",
        "vivre",
        "voici",
        "voie",
        "voilà",
        "voile",
        "voir",
        "voisin",
        "voisin",
        "voiture",
        "voix",
        "vol",
        "voler",
        "volonté",
        "votre",
        "vouloir",
        "vous",
        "voyage",
        "voyager",
        "vrai",
        "vraiment",
        "vue",
        "y",
        "yeux",
    )

    parts_of_speech: Dict[str, tuple] = {}



from .. import Provider as SsnProvider


class Provider(SsnProvider):
    # The FIN code consists of 7 characters (letters and numbers of the English alphabet,
    # except for the letters "I" and "O").

    characters = [
        "A",
        "B",
        "C",
        "D",
        "E",
        "F",
        "G",
        "H",
        "J",
        "K",
        "L",
        "M",
        "N",
        "P",
        "Q",
        "R",
        "S",
        "T",
        "U",
        "V",
        "W",
        "X",
        "Y",
        "Z",
    ]
    numbers = ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"]
    all_characters = characters + numbers

    def ssn(self) -> str:
        ssn = "".join(self.random_elements(elements=self.all_characters, length=7))
        return ssn
